( cd usr/lib ; rm -rf libpolyp-0.7.so.0 )
( cd usr/lib ; ln -sf libpolyp-0.7.so.0.0.0 libpolyp-0.7.so.0 )
( cd usr/lib ; rm -rf libpolyp-0.7.so )
( cd usr/lib ; ln -sf libpolyp-0.7.so.0.0.0 libpolyp-0.7.so )
( cd usr/lib ; rm -rf libpolyp-error-0.7.so.0 )
( cd usr/lib ; ln -sf libpolyp-error-0.7.so.0.0.0 libpolyp-error-0.7.so.0 )
( cd usr/lib ; rm -rf libpolyp-error-0.7.so )
( cd usr/lib ; ln -sf libpolyp-error-0.7.so.0.0.0 libpolyp-error-0.7.so )
( cd usr/lib ; rm -rf libpolyp-mainloop-0.7.so.0 )
( cd usr/lib ; ln -sf libpolyp-mainloop-0.7.so.0.0.0 libpolyp-mainloop-0.7.so.0 )
( cd usr/lib ; rm -rf libpolyp-mainloop-0.7.so )
( cd usr/lib ; ln -sf libpolyp-mainloop-0.7.so.0.0.0 libpolyp-mainloop-0.7.so )
( cd usr/lib ; rm -rf libpolyp-simple-0.7.so.0 )
( cd usr/lib ; ln -sf libpolyp-simple-0.7.so.0.0.0 libpolyp-simple-0.7.so.0 )
( cd usr/lib ; rm -rf libpolyp-simple-0.7.so )
( cd usr/lib ; ln -sf libpolyp-simple-0.7.so.0.0.0 libpolyp-simple-0.7.so )
( cd usr/lib ; rm -rf libpolyp-mainloop-glib-0.7.so.0 )
( cd usr/lib ; ln -sf libpolyp-mainloop-glib-0.7.so.0.0.0 libpolyp-mainloop-glib-0.7.so.0 )
( cd usr/lib ; rm -rf libpolyp-mainloop-glib-0.7.so )
( cd usr/lib ; ln -sf libpolyp-mainloop-glib-0.7.so.0.0.0 libpolyp-mainloop-glib-0.7.so )
( cd usr/lib ; rm -rf libpolyp-mainloop-glib12-0.7.so.0 )
( cd usr/lib ; ln -sf libpolyp-mainloop-glib12-0.7.so.0.0.0 libpolyp-mainloop-glib12-0.7.so.0 )
( cd usr/lib ; rm -rf libpolyp-mainloop-glib12-0.7.so )
( cd usr/lib ; ln -sf libpolyp-mainloop-glib12-0.7.so.0.0.0 libpolyp-mainloop-glib12-0.7.so )
( cd usr/bin ; rm -rf parec )
( cd usr/bin ; ln -sf pacat parec )
